@@ -30,6 +30,9 @@ class AsyncClient(BaseClient, doc_prefix="|coro|"):
     async def close(self):
         await self._state.http.close()
 
+    # --------------------------------------------------------------------------
+    # CodinGamer
+
     async def login(
         self,
         email: typing.Optional[str] = None,
@@ -78,17 +81,21 @@ class AsyncClient(BaseClient, doc_prefix="|coro|"):
                 raise  # pragma: no cover
             handle = data["publicHandle"]
 
-        if handle is None and not CODINGAMER_HANDLE_REGEX.match(codingamer):
-            results = await self._state.http.search(codingamer)
-            users = [result for result in results if result["type"] == "USER"]
-            if users:
-                handle = users[0]["id"]
+        else:
+            if CODINGAMER_HANDLE_REGEX.match(codingamer):
+                handle = codingamer
             else:
-                raise NotFound.from_type(
-                    "codingamer", f"No CodinGamer with username {codingamer!r}"
-                )
-        elif handle is None:
-            handle = codingamer
+                results = await self._state.http.search(codingamer)
+                users = [
+                    result for result in results if result["type"] == "USER"
+                ]
+                if users:
+                    handle = users[0]["id"]
+                else:
+                    raise NotFound.from_type(
+                        "codingamer",
+                        f"No CodinGamer with username {codingamer!r}",
+                    )
 
         data = await self._state.http.get_codingamer_from_handle(handle)
         if data is None:
@@ -97,6 +104,9 @@ class AsyncClient(BaseClient, doc_prefix="|coro|"):
             )
         return CodinGamer(self._state, data["codingamer"])
 
+    # --------------------------------------------------------------------------
+    # Clash of Code
+
     async def get_clash_of_code(self, handle: str) -> ClashOfCode:
         if not CLASH_OF_CODE_HANDLE_REGEX.match(handle):
             raise ValueError(
@@ -120,19 +130,66 @@ class AsyncClient(BaseClient, doc_prefix="|coro|"):
             return None  # pragma: no cover
         return ClashOfCode(self._state, data[0])  # pragma: no cover
 
+    # --------------------------------------------------------------------------
+    # Language IDs
+
     async def get_language_ids(self) -> typing.List[str]:
         return await self._state.http.get_language_ids()
 
+    # --------------------------------------------------------------------------
+    # Notifications
+
     async def get_unseen_notifications(self) -> typing.Iterator[Notification]:
         if not self.logged_in:
             raise LoginRequired()
 
-        data = await self._state.http.get_unseen_notifications(
-            self.codingamer.id
-        )
+        try:
+            data = await self._state.http.get_unseen_notifications(
+                self.codingamer.id
+            )
+        except HTTPError as error:
+            if error.data["id"] == 492:
+                raise LoginRequired() from None
+            raise  # pragma: no cover
+
         for notification in data:
             yield Notification(self._state, notification)
 
+    async def get_unread_notifications(self) -> typing.Iterator[Notification]:
+        if not self.logged_in:
+            raise LoginRequired()
+
+        try:
+            data = await self._state.http.get_unread_notifications(
+                self.codingamer.id
+            )
+        except HTTPError as error:
+            if error.data["id"] == 492:
+                raise LoginRequired() from None
+            raise  # pragma: no cover
+
+        for notification in data:
+            yield Notification(self._state, notification)
+
+    async def get_read_notifications(self) -> typing.Iterator[Notification]:
+        if not self.logged_in:
+            raise LoginRequired()
+
+        try:
+            data = await self._state.http.get_last_read_notifications(
+                self.codingamer.id
+            )
+        except HTTPError as error:
+            if error.data["id"] == 492:
+                raise LoginRequired() from None
+            raise  # pragma: no cover
+
+        for notification in data:
+            yield Notification(self._state, notification)
+
+    # --------------------------------------------------------------------------
+    # Leaderboards
+
     async def get_global_leaderboard(
         self, page: int = 1, type: str = "GENERAL", group: str = "global"
     ) -> GlobalLeaderboard:
