@@ -5,18 +5,27 @@ import requests
 from .base import BaseHTTPClient
 from .httperror import HTTPError
 
+if typing.TYPE_CHECKING:
+    from ..state import ConnectionState
+
+
 __all__ = ("SyncHTTPClient",)
 
 
 class SyncHTTPClient(BaseHTTPClient):
-    def __init__(self):
+    def __init__(self, state: "ConnectionState"):
+        self.state = state
         self.__session: requests.Session = requests.Session()
 
+    @property
+    def is_async(self) -> bool:
+        return False
+
     def close(self):
         self.__session.close()
 
     def request(self, service: str, func: str, parameters: list = []):
-        url = self.BASE + service + "/" + func
+        url = self.API_URL + service + "/" + func
         with self.__session.post(
             url, json=parameters, headers=self.headers
         ) as response:
